<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="oc" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>A prepaus</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Categoria :</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Aviar lo torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Verificar pas las donadas del torrent</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Uncategorized</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resume torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit category...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Quitter qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Un sol ligam per linha</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Lo limit global per la velocitat de mandadís deu èsser superior a 0 o desactivat.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Lo limit global per la velocitat de recepcion deu èsser superior a 0 o desactivat.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Lo limit alternatiu per la velocitat de mandadís deu èsser superior a 0 o desactivat.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Lo limit alternatiu per la velocitat de recepcion deu èsser superior a 0 o desactivat.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Lo nombre maximum de telecargaments actius deu èsser superior a -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Lo nombre maximum de mandadisses actius deu èsser superior a -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Lo nombre maximum de torrents actius deu èsser superior a -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Lo nombre maximum de connexions deu èsser superior a 0 o desactivat.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Lo nombre maximum de connexions per torrent deu èsser superior a 0 o desactivat.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Lo nombre maximum de slots de mandadís per torrent deu èsser superior a 0 o desactivat.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Impossible de salvar las preferéncias, qBittorrent es probablament inaccessible.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Lo pòrt utilizat per las connexions entrantas deu èsser comprés entre 1 e 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Lo pòrt utilizat per l'interfàcia Web deu èsser comprés entre 1024 e 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Impossible de se connectr, qBittorrent es probablament inaccessible.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Nom d'utilizaire o senhal invalid.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Password</source>
        <translation>Senhal</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Identificant</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Autors originaux</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Apondre</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Mandar de torrents</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Salvar los fichièrs dins :</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie :</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Entratz lo dorsièr aicí</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Mai d'informacions</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informacion suls certificats</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Limit download rate</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Rename torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Autre...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Diluns</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dimars</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dimècres</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dijòus</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Divendres</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dissabte</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dimenge</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Se desconnectar</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Telecargar los torrents dempuèi lors URLs o ligams Magnet</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Transferir un torrent local</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Sètz segur que volètz suprimir los torrents seleccionats de la lista de transferiment ?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Lo logicial qBittorrent es pas accessible</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to create category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Free space: %1</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Saving Management</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Edicion</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Aisinas</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fichièr</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Afichatge</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opcions...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Aviar</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Prioritat minimala</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Prioritat maximala</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Demesir la prioritat</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Aumentar la prioritat</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Barra d'aisinas</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Velocitat dins lo títol de la fenèstra</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Far un don !</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Aviar tot</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estatisticas</translation>
    </message>
    <message>
        <source>About</source>
        <translation>A prepaus</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Metre en pausa</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suprimir</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Tout metre en pausa</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Apondre un fichièr torrent…</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Documentacion</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Apondre ligam cap a un torrent…</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Òc</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Limit global de la velocitat de mandadís</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Limit global de la velocitat de recepcion</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[R : %1, E : %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search Engine</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Transfers</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Telecargaments</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocitat</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Interfàcia web</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Lenga</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP Filtering</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP address:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Server domains:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Servidor SMTP :</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentificacion</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d'utilizaire :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senhal :</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Listening Port</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connections Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Proxy Server</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipe :</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Pas cap)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Òste :</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Pòrt :</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload:</source>
        <translation>Mandadís :</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Telecargament :</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>De :</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>A :</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Quora :</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Cada jorn</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Jorns de setmana</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Fins de setmanas</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Privacy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Require encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disable encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>then</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause them</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove them</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certificat :</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Clau :</translation>
    </message>
    <message>
        <source>Register</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nom de domeni :</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N : Nom del torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L : Categoria</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D : Camin de salvament</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C : Nombre de fichièrs</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB/s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Change current password</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Files location:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Pòrt</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Indicadors</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Logicial</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Progression</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Velocitat DL</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Velocitat UP</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Telecargat</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Mandat</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Pertinéncia</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Fichièrs</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>País</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normala</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Nauta</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maximala</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trackers</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Pars</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Fonts HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Contengut</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Telecargat :</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transferiment</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Actiu pendent :</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Temps restant :</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Mandat :</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Fonts :</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Velocitat de telecargament :</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Velocitat d'emission :</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Pars :</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Limit de telecargament :</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Limit de mandadís :</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Degalhat :</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Connexions :</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacions</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Comentari :</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Ratio de partiment :</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Anonciar dins :</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Darrièra fois vu complet :</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Talha totala :</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Tròces :</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Creat per :</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Apondut lo :</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Completat lo :</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Creat lo :</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Hachage del torrent :</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Camin de salvament :</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Pas jamai</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 × %2 (a %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 aquesta session)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 maximum)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 total)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 en mejana)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload limit:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Repertòri susvelhat</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Remplaçar l'emplaçament de salvament</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Repertòri susvelhat</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Emplaçament de salvament per défaut</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>Kio/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Estatisticas</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Estatisticas utilizaire</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Estatisticas del tampon</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Succès de tampon en lectura :</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Temps mejan passat en fila d'espèra :</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time download:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session waste:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time upload:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Estatisticas de performància</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Accions d'E/S en fila d'espèra :</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Subrecarga del tampon d'escritura :</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Subrecarga del tampon de lectura :</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Talha totala dels fichièrs en fila d'espèra :</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT : %1 nosèls</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Totes  (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>En Telecargament (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>En Partiment (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Acabats (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Aviats (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>En Pausa (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Actius (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inactius (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Error (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Totes (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>En Telecargament (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>En Partiment (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Acabats (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>En Pausa (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Aviats (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Actius (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inactius (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Error (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Talha</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progression</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Prioritat de telecargament</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Restant</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Talha</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Progression</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Estatut</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Fonts</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Pars</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Velocitat DL</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Velocitat UP</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Ratio</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Temps restant</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Apondut lo</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Acabat lo</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Limit recepcion</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Limit mandadís</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Telecargat</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Mandat</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Telecargament de la session</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Emission de la session</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Restant</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Actiu pendent</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Camin de salvament</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Acabat</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Limit de ratio</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Darrièr còp vist complet</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Darrièra activitat</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Talha totala</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estatut</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Pars</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Messatge</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Updating...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>#</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker editing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leeches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tracker</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Fenèstra d'apondon de trackers</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Lista dels trackers d'apondre (un per linha) :</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>i a %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Moving</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Errored</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Missing Files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued for checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking resume data</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Estatut</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categorias</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Limitacion de la velocitat de recepcion</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Limitacion de la velocitat d'emission</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomenar</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Aviar</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Forçar la represa</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Metre en pausa</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Suprimir</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Limitar lo ratio de partiment…</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Limitar la velocitat de mandadís…</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Limitar la velocitat de recepcion…</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Desplaçar cap amont</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Desplaçar cap aval</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Desplaçar cap amont</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Desplaçar cap aval</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Camin de salvament…</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Copiar nom</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Telecargar primièras e darrièras pèças en primièr</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Gestion de torrent automatique</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Novèla…</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Reïnicializar</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioritat</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Forçar una reverificacion</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Copiar lo ligam magnet</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Mòde de superpartiment</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Renomenar…</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Telecargament sequencial</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Force reannounce</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save path</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Limitacion del ratio de partiment</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set no share limit</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set share limit to</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>ratio</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Un client avançat BitTorrent programat en C++, basat sus l'aisina Qt e libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Pagina d'acuèlh :</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum :</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Seguiment de Bugs :</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Suprimir tanben los fichièrs sul disc</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation>Telecargar</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>Oct</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>Kio</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>Mio</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>Gio</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>Tio</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>Pio</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>Eio</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1j %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Desconeguda</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1min</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1min</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Plugin path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>URL or local directory</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install plugin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All plugins</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All categories</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search in:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Go to description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Results (showing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent names only</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Only enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>out of</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Everywhere</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install new plugin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Check for updates</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leechers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeders</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished" />
    </message>
</context>
</TS>